@@ -1,8 +1,8 @@
 import sys,os
 sys.path.append('.')
-import pickle
+import pickle,numpy as np
 
-__version__ = '0.1.6'
+__version__ = '0.1.7'
 __author__ = 'Jakob Lass'
 
 # installFolder = os.path.abspath(os.path.split(__file__)[0])
@@ -27,4 +27,11 @@ except FileNotFoundError:
 
     with open(foundFile,'rb') as f:
         calibrationDict = pickle.load(f)
-    #raise FileNotFoundError
\ No newline at end of file
+    #raise FileNotFoundError
+
+    
+calib2021 = {'limits':np.array([1]),
+             'names':np.array(['Mockup']),
+             'Mockup':np.ones((1152,128))}
+
+calibrationDict[2021] = calib2021
\ No newline at end of file
